#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : padding
# @Time         : 2020-04-10 14:11
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :

from sklearn.utils.murmurhash import murmurhash3_32

def murmurhash(key="key", value="value", bins=10000):
    hashValue = murmurhash3_32(f"{key}:{value}")
    return abs(hashValue) % bins


print(murmurhash())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : Mysql
# @Time         : 2020/4/16 8:12 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :

import pymysql


class Mysql(object):

    def __init__(self, host='10.136.128.113', port=6071, user='browser_c3_s', passwd='8d8b9339efef09794c8ea2267589b2bc',
                 db='browser'):
        """
        m = Mysql()
        df = pd.read_sql('select doc_id, title from push_daily_news', m.conn)

        sql = "select * from algo_job_common where job_id='每日浏览器push--大数据94%vs自建旧3%vs自建新3%'"

        :param host:
        :param port:
        :param user:
        :param passwd:
        :param db:
        """
        self.conn = pymysql.connect(host=host, port=port, user=user, passwd=passwd, db=db)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : Python.
# @File         : zk
# @Time         : 2020-03-11 13:25
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : https://blog.csdn.net/asty9000/article/details/96430990
# http://zkview.d.xiaomi.net/clusters/tjwqstaging/nodes

import time
import yaml
from kazoo.client import KazooClient
from ..config import Config

zk = KazooClient(hosts="tjwqstaging.zk.hadoop.srv:11000")
zk.start()


class Config_(object):
    zk_cfg = None
    email_cfg = None


@zk.DataWatch('/mipush/hive')
def watcher(data, stat):  # (data, stat, event)
    cfg = yaml.safe_load(data)
    print(f"Config Version: {stat.version}")
    print(cfg)
    Config.zk_cfg = cfg

    Config_.zk_cfg = cfg
    # print("Event is %s" % event)

def zk_watcher(path='/mipush/hive'):
    @zk.DataWatch(path)
    def watcher(data, stat):  # (data, stat, event)
        cfg = yaml.safe_load(data)
        Config.zk_cfg = cfg


# @zk.DataWatch('/mipush/xx')
# def watcher(data, stat):  # (data, stat, event)
#     cfg = yaml.safe_load(data)
#     Config.zk_cfg = cfg

# import schedule
# def zk_schedule():
#     schedule.every(3).seconds.do(lambda x: x)  # 每隔5秒读一次zk配置
#     while True:
#         schedule.run_pending()
#         time.sleep(1)


if __name__ == '__main__':
    # zk_schedule()
    while True:
        time.sleep(3)
        print('ok')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : __init__.py
# @Time         : 2019-12-10 17:24
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import sys
from loguru import logger
trace1 = logger.add(
    'runtime_{time}.log',
    rotation="100 MB",
    retention='10 days',
    level="INFO",
    catch=True
)
logger.info("xxxx")
logger.debug('this is a debug message')
logger.info('this is a info message')


if __name__ == '__main__':
    @logger.catch()
    def f():
        1 / 0
        return 1111


    print(f())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : search_data_transform
# @Time         : 2020/6/8 3:31 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import os
import datetime
import numpy as np
import pandas as pd
import jieba.analyse as ja
from tqdm.auto import tqdm
from loguru import logger

from pathlib import Path
from gensim.models.fasttext import load_facebook_model
from concurrent.futures import ProcessPoolExecutor

logger.add('./scheduler.log',
           rotation="100 MB",
           enqueue=True,  # 异步
           encoding="utf-8",
           backtrace=True,
           diagnose=True,
           level="INFO")

_norm = lambda x, ord=1: x / np.linalg.norm(x, ord, axis=len(x.shape) > 1, keepdims=True)

delta = 1
data_name = "search_sequence_data"
base_path = "/user/h_data_platform/platform/browser/algo/data/biz"
date = str(datetime.datetime.now() - datetime.timedelta(delta))[:10].replace("-", "")

# 加载词向量
logger.info("加载词向量")
wv = load_facebook_model("/home/work/yuanjie/skipgram.title").wv


def topk_words_vec(q):
    vec = np.zeros(200)
    ws = ja.tfidf(q, topK=8)
    # print(ws)
    if ws:
        for w in ws:
            vec += wv[w] / len(ws)
        vec = _norm(vec)
    return " ".join(map(str, vec.tolist()))


# 下载数据
logger.info("下载数据")
os.system(f"hdfs --cluster zjyprc-hadoop dfs -get {base_path}/search/search_sequence_agg/date={date} ./{data_name}")

# 预处理并上传数据
logger.info("创建目录")
os.system(f"hdfs --cluster zjyprc-hadoop dfs -mkdir -p {base_path}/search/online/v1/date={date}")

# 获取句向量
logger.info("获取句向量")


def get_vec(args):
    i, file_name = args
    df = pd.read_parquet(f"{file_name}") \
        .assign(query=lambda df: df['query'].map(lambda x: " ".join(x))) \
        .assign(features=lambda df: df['query'].map(topk_words_vec)) \
        .rename(columns={'imei': 'id'})

    with open(f'part-{i}', 'w') as f:
        _ = "\n".join(map(str, df[['id', 'features']].to_dict('records')))
        f.write(_)


with ProcessPoolExecutor(16) as pool:
    _ = list(pool.map(get_vec, enumerate(Path(f"./{data_name}").glob("*.parquet"))))

# 上传数据
os.system(f"hdfs --cluster zjyprc-hadoop dfs -put ./part-* {base_path}/search/online/v1/date={date}")

# 成功标识
logger.info("上传_SUCCESS")
os.system(f"touch ./_SUCCESS")
os.system(f"hdfs --cluster zjyprc-hadoop dfs -put ./_SUCCESS {base_path}/search/online/v1/date={date}")

# 删除数据
logger.info("删除数据")
os.system(f"rm -rf {data_name} && rm part*")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : report
# @Time         : 2020-03-21 18:51
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import pandas as pd

""":arg
[['source', 'deviceid'],
 ['1', '9736971fbceefd95b55bee7c9de441ad'],
 ['1', '8ec2741c37e1a6030b4e87bfd63b7c81'],
 ['1', 'b0cc41b7b3f6b0411edccfbc3e8f6ac3'],
 ['1', 'ae7ef70abe557100cc716a979b143afb'],
 ['1', 'ae7ef70abe557100cc716a979b143afb']]
"""


def __getattribute__(job_type):
    return eval(job_type)


def hive(data_str):
    if data_str:
        data = eval(data_str)
        return pd.DataFrame(data[1:], columns=data[0])
    else:
        return pd.DataFrame()


def spark(data_str):
    if data_str:
        return pd.DataFrame(eval(data_str))  # TODO:spark统一格式
    else:
        return pd.DataFrame()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : Hive
# @Time         : 2020/4/22 4:56 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import os
from pyhive import hive


class Hive(object):

    def __init__(self, keytab="/fds/data/h_browser.keytab"):
        self.kinit(keytab)

    @property
    def conn(self):
        """
        conn = hive_conn()
        sql='select count(1) from browser.mipush_browser_label'
        def get_df(sql):
            df = pd.read_sql(sql, conn)
            df.columns = [col.split('.')[1] if '.' in col else col for col in df.columns]
            return df

        """

        conn = hive.connect(
            host="zjyprc-hadoop.hive.srv", port=10000,
            auth="KERBEROS", kerberos_service_name="sql_prc",
            configuration={
                'mapreduce.map.memory.mb': '10240',
                'mapreduce.reduce.memory.mb': '10240',
                'mapreduce.map.java.opts': '-Xmx3072m',
                'mapreduce.reduce.java.opts': '-Xmx3072m',
                'hive.input.format': 'org.apache.hadoop.hive.ql.io.HiveInputFormat',
                'hive.limit.optimize.enable': 'false',
                'mapreduce.job.queuename': 'root.production.miui_group.browser.miui_browser_zjy_1',  # zjy
            },
        )
        return conn

    @staticmethod
    def kinit(keytab="/fds/data/h_browser.keytab"):
        cmd = f"kinit -k -t {keytab} h_browser@XIAOMI.HADOOP && klist"
        _ = os.popen(cmd).read()
        print(_)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : s
# @Time         : 2019-11-01 10:23
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : https://github.com/streamlit/streamlit/tree/develop/lib/streamlit/hello

import os
import time
import datetime
import streamlit as st
import numpy as np
import pandas as pd

st.title("Streamlit App")  # st.markdown("# Push Report")
# 刷新
st.button('Re-Run')

st.write("## 输入")
_ = st.time_input('设置时间', datetime.time(8, 45))
st.write('time_input:', _)  # 支持 markdown

_ = st.date_input('设置日期', datetime.datetime.today())
st.write('date_input:', _)

_ = st.number_input('设置数值', 666)
st.write('number_input:', _)

_ = st.text_input('设置文本', 'text_input')
st.write('text_input:', _)

st.write("## 选项")
_ = st.selectbox('下拉项', range(5))
st.write('selectbox:', _)

_ = st.multiselect('多选项', 'abcde', 'abc')
st.write('You selected:', _)

_ = st.checkbox('小框框')
st.write('小框框:', _)


x = st.slider('Select a value')
st.write(x, 'squared is', x * x)

# 拉取 Mongo 数据
dataframe = pd.DataFrame(np.random.randn(3, 5), columns=('col %d' % i for i in range(5)))
st.dataframe(dataframe.style.highlight_max(axis=0))  # st.table

# image
from PIL import Image

image = Image.open('/Users/yuanjie/Desktop/xm.jpg')
st.write("## 图片")
st.image(image, caption='Sunrise by the mountains', use_column_width=False)

# info
st.success('This is a success message!')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : Python.
# @File         : zk_app
# @Time         : 2020-03-11 14:39
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


# !/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : Python.
# @File         : app
# @Time         : 2020-03-11 13:54
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : http://zkview.d.xiaomi.net/clusters/tjwqstaging/nodes?path=%2Fmipush%2Fhive&isAdmin=false


import time
import pandas as pd
from typing import Optional
from fastapi import FastAPI, Form, Depends, File, UploadFile
from pydantic import BaseModel
from starlette.staticfiles import StaticFiles
from starlette.requests import Request
from starlette.responses import \
    RedirectResponse, FileResponse, HTMLResponse, PlainTextResponse
from starlette.status import *

from ..utils.zk_client import Config  # 获取zk配置

ROUTE = ""
app = FastAPI(
    debug=True,
    openapi_url=f"{ROUTE}/openapi.json",
    docs_url=f"{ROUTE}/docs",
    redoc_url=f"{ROUTE}/redoc",
    swagger_ui_oauth2_redirect_url=f"{ROUTE}/docs/oauth2-redirect"
)


@app.get("/")
async def read_root():
    print(f"App: {Config.zk_cfg}")
    return {"Hello": "World"}


if __name__ == '__main__':
    import os
    import socket

    me = socket.gethostname() == 'yuanjie-Mac.local'

    uvicorn = "uvicorn" if me else "/opt/soft/python3/bin/uvicorn"

    main_file = __file__.split('/')[-1].split('.')[0]

    # --reload测试环境
    os.system(f"uvicorn {main_file}:app --reload --host 0.0.0.0 --port 8000")
